<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Suodatus:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Valitse päätteen fontti</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Fontti:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Koko:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>Bookmarks</source>
        <translation>Suosikit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Paina &quot;%1&quot; avataksesi päätteen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Seuraava välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Edellinen välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>Siirrä välilehti &amp;vasemmalle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>Siirrä välilehti &amp;oikealle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Jaa pääte vaakas&amp;uunnassa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Jaa pääte p&amp;ystysuunnassa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Pienennä alapääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Tyhjennä aktiivinen pääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Keep window open when it loses focus</source>
        <translation>Jätä auki aktiivisen ikkunan vaihtuessa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Viimeksi käytetty välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Seuraavaksi käytetty välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation>Välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation>Siirry</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Ylempi alipääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Alempi alipääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Vasen alipääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Oikea alipääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Kopioi valinta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>&amp;Liitä leikepöytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>Liitä v&amp;alinta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>Lä&amp;hennä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>Loito&amp;nna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>Palauta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>&amp;Etsi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Handle history...</source>
        <translation>Käsittele historiaa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>&amp;Save Session</source>
        <translation>Tallenna i&amp;stunto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Lataa istunto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Näytä valikko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Rename session</source>
        <translation>Nimeä istunto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Uusi välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Uusi välilehti &amp;pikavalinnasta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;pääte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 päätettä &amp;vaakasuorassa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 päätettä &amp;pystysuorassa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 pää&amp;tettä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sulje välilehti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;New Window</source>
        <translation>&amp;Uusi ikkuna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Asetukset...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Piilota ikkunan reunat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Näytä välilehtipalkki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Toggle Bookmarks</source>
        <translation>Vaihda kirjanmerkkejä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Alhaalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Top</source>
        <translation>&amp;Ylhäällä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>&amp;Right</source>
        <translation>&amp;Oikealla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;Left</source>
        <translation>&amp;Vasemmalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Välilehtien asettelu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>&amp;None</source>
        <translation>&amp;Ei mitään</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Vierityspalkin asettelu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Laatikko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Vaakaviiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Pystyviiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Näppäimistön osoittimen muoto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Exit QTerminal</source>
        <translation>Poistu QTerminalista</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Do not ask again</source>
        <translation>Älä kysy uudelleen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Are you sure you want to exit?</source>
        <translation>Haluatko varmasti poistua?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>About</source>
        <translation>Tietoa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Kevyt ja tehokas pääte-emulaattori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Copyright (C) </source>
        <translation>Tekijänoikeus (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>LXQt Project</source>
        <translation>LXQt-hanke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Development: </source>
        <translation>Kehitys: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Päätteen asetukset</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Käytös</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Pudotusvalikko</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Kirjanmerkit</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Piilota välilehtipalkki vain yhden välilehden auki ollessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Väriskeema</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Vierityspalkin sijainti</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Aloitusnäkymä:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Näytä reunus nykyisen terminaalin ympärillä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Päätteen läpinäkyvyys</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Sovelluksen läpinäkyvyys</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Normaali (yksi pääte)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 päätettä vaakasuorassa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 päätettä pystysuorassa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 päätettä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Fontti</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Muuta...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Välilehtien asettelu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Pienoisohjelman tyyli</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Näytä valikkopalkki</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Osoittimen muoto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Muuta ikkunan otsikko käytössä olevan päätteen mukaan</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Muuta ikkunan ikoni käytössä olevan päätteen mukaan</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Ota käyttöön kaksisuuntainen tekstinsyöttö</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Taustakuva:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Valitse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Näytä päätteen koko sitä muuttaessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Pysyvä välilehden koko:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Näytä sulkemisnappi kaikissa välilehdissä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Päätteen marginaali</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Käytä fontin laatikon-piirtomerkkejä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Pikakomennot aktivoidaan Alt-painikkeella, joka saattaa vaikuttaa päätteen toimintaan.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Poista valikon pikakomennot käytöstä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="813"/>
        <source>Emulation</source>
        <translation>Emulointi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Toiminta liittämisen jälkeen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Confirm multiline paste</source>
        <translation>Pyydä vahvistus useita rivejä kerralla liitettäessä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="651"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Poista uudet rivit liitetyn tekstin lopusta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="747"/>
        <source>Open new terminals in current working directory</source>
        <translation>Avaa uusia päätteitä nykyisessä työhakemistossa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="682"/>
        <source>Save Size when closing</source>
        <translation>Tallenna koko suljettaessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Save Position when closing</source>
        <translation>Tallenna sijainti suljettaessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Ask for confirmation when closing</source>
        <translation>Kysy vahvistusta suljettaessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Rajoittamaton historia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Historian koko (riveinä)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Default $TERM</source>
        <translation>Oletus $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="694"/>
        <source>Start with this size:</source>
        <translation>Aloituskoko:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Taustan tila:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Venytetty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Lähennetty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Sovitettu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Käytetäänkö geometristen kirjasimien piirtoon QTerminalin omia toimintoja, vai kirjasimen piirtoon liittyviä kirjastoja.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Käytetäänkö lihavoidun fontin piirtoon vahvoja värejä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Käytä lihavoitua fonttia vahvoille väreille</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Piilota ikkunakehykset</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="822"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Valitsee mitä käyttöjärjestelmää emuloidaan. Huomaa, ettei tämä ei ole riippuvainen käytössä olevasta käyttöjärjestelmästä.&lt;/p&gt;&lt;p&gt;Epävarmoissa tapauksissa kannattaa käyttää &lt;span style=&quot; font-weight:600;&quot;&gt;oletus&lt;/span&gt; vaihtoehtoa.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="800"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Tämä komento suoritetaan käyttäen vierityshistorian sisältävän väliaikaistiedoston nimeä sen parametrina</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="803"/>
        <source>Handle history command</source>
        <translation>Historian käsittely -komento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="701"/>
        <location filename="../forms/propertiesdialog.ui" line="715"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="722"/>
        <source>Get current size</source>
        <translation>Hae nykyinen koko</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Avaa uusi välilehti aktiivisen välilehden oikealle puolelle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="754"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Jos tämä valinta on tyhjä, uusi välilehti avataan oikeaan reunaan</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="658"/>
        <source>Close tab on middle-click</source>
        <translation>Sulje välilehti keskipainikkeella</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Pakota &quot;bracketed paste&quot; toiminto pois käytöstä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>&quot;Bracketed paste&quot; on käytännöllinen useita rivejä kerralla liitettäessä.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>Audible bell</source>
        <translation>Äänimerkki</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="846"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Pikanäppäinten muokkaus:
1. Kaksoisklikkaa painiketta
2. Paina ja vapauta haluttu yhdistelmä
3. Klikkaa pikanäppäintä tai oaina Enter

Pikanäppäimen poistamiseksi, paina 2 -kohdassa vain muuttajanäppäintä (kuten Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="876"/>
        <source>Shortcut</source>
        <translation>Pikanäppäin</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="881"/>
        <source>Key</source>
        <translation>Näppäin</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Show on start</source>
        <translation>Näytä käynnistyksessä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="900"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Lukituspainike näytetään vaakasuorassa välilehtipalkissa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="903"/>
        <source>Keep window open when it loses focus</source>
        <translation>Pidä ikkuna avoinna kohdistuksen vaihtuessa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="921"/>
        <source>Height</source>
        <translation>Korkeus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Width</source>
        <translation>Leveys</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="962"/>
        <source>Shortcut:</source>
        <translation>Pikanäppäin:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1029"/>
        <source>Edit bookmark file contents</source>
        <translation>Muokkaa kirjainmerkkitiedoston sisältöä</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Enable bookmarks</source>
        <translation>Ota kirjainmerkit käyttöön</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="997"/>
        <source>Bookmark file</source>
        <translation>Kirjainmerkki tiedosto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1010"/>
        <source>Find...</source>
        <translation>Hae...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Voit määritellä kirjainmerkkitiedoston sijainnin tässä. Tämä mahdollistaa helpon jakamisen esimerkiksi OwnCloudin tai DropBoxin kautta.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Ei vierityspalkkia</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Vasemmalla</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Oikealla</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Ylhäällä</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Alhaalla</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Laatikko</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Alaviiva</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Pystyviiva</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Ei mitään</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Vieritys ylös</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Vieritys alas</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="268"/>
        <source>Examples</source>
        <translation>Esimerkit</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Kuvat (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="511"/>
        <source>Open bookmarks file</source>
        <translation>Avaa krjanmerkkitiedosto</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="513"/>
        <source>XML files (*.xml)</source>
        <translation>XML-tiedostot (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>All files (*)</source>
        <translation>Kaikki tiedostot (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>Question</source>
        <translation>Kysymys</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Haluatko korvata tämän kirjanmerkkitiedoston?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Kirjanmerkkitiedoston pääte ei ole &apos;.xml&apos;.
Haluatko varmasti korvata sen?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Kirjanmerkkejä ei voi kirjoittaa tähän tiedostoon:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="203"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Järjestelmän oletus</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="420"/>
        <source>Choose a background image</source>
        <translation>Valitse taustakuva</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synkronoinut kirjanmerkit</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <location filename="../tabwidget.cpp" line="234"/>
        <source>Shell No. %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="202"/>
        <source>Tab name</source>
        <translation>Välilehden nimi</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>New tab name:</source>
        <translation>Uuden välilehden nimi:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>Select new tab title color</source>
        <translation>Valitse uusi välilehden otsikon väri</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="252"/>
        <source>Close session</source>
        <translation>Sulje istunto</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Change title color</source>
        <translation>Muuta otsikon väri</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Lataa istunto</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Tallennetut istunnot:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>PääIkkuna</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>T&amp;oiminnot</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>O&amp;hje</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Tietoja...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Tietoja &amp;Qt:stä...</translation>
    </message>
</context>
</TS>
